@@ -6,54 +6,64 @@ from __future__ import ( division, absolute_import,
                          print_function, unicode_literals )
 
 import sys, os, tempfile, logging
-try:    import urllib2
-except: import urllib.request as urllib2
+
+if sys.version_info >= (3,):
+    import urllib.request as urllib2
+    import urllib.parse as urlparse
+else:
+    import urllib2
+    import urlparse
 
 
 def step_1():
-    logging.info("Installing Distribute")
+    logging.info("Checking Setuptools/Distribute")
     try:
-        import pkg_resources
-        logging.info("Distribute already installed!")
-    except:
-        logging.info("Installing Distribute...")
+        import setuptools
+        logging.info("Setuptools/Distribute installed!")
+    except ImportError:
+        logging.info("Installing Setuptools...")
 
-        url = "http://python-distribute.org/distribute_setup.py"
+        url = "https://bitbucket.org/pypa/setuptools/downloads/ez_setup.py"
         dtemp = tempfile.mkdtemp()
         filename = download_file(url, dtemp)
         os.system("{0} {1}".format(sys.executable, filename))
 
 
 def step_2():
-    logging.info("Installing Pip")
+    logging.info("Checking Pip")
     try:
         import pip
-        logging.info("Pip already installed!")
-    except:
+        logging.info("Pip installed!")
+    except ImportError:
         logging.info("Installing Pip...")
 
         from pkg_resources import load_entry_point
         packages_list = [
             'pip',
         ]
-        install_func = load_entry_point('distribute', 'console_scripts', 'easy_install')
+        install_func = load_entry_point('setuptools', 'console_scripts', 'easy_install')
         return install_func(packages_list)
 
 
 #recipe from http://stackoverflow.com/questions/22676/how-do-i-download-a-file-over-http-using-python
 def download_file(url, desc=None):
     u = urllib2.urlopen(url)
-    filename = url.split('/')[-1]
+
+    scheme, netloc, path, query, fragment = urlparse.urlsplit(url)
+    filename = os.path.basename(path)
     if not filename:
-        filename = 'file.dat'
+        filename = 'downloaded.file'
     if desc:
         filename = os.path.join(desc, filename)
 
     with open(filename, 'wb') as f:
         meta = u.info()
         meta_func = meta.getheaders if hasattr(meta, 'getheaders') else meta.get_all
-        file_size = int(meta_func("Content-Length")[0])
-        print("Downloading: %s Bytes: %s" % (url, file_size))
+        meta_length = meta_func("Content-Length")
+        file_size = None
+        if meta_length:
+            file_size = int(meta_length[0])
+        print("Downloading: {0} Bytes: {1}".format(url, file_size))
 
         file_size_dl = 0
         block_sz = 8192
@@ -64,9 +74,13 @@ def download_file(url, desc=None):
 
             file_size_dl += len(buffer)
             f.write(buffer)
-            status = r"%10d  [%3.2f%%]" % (file_size_dl, file_size_dl * 100. / file_size)
-            status = status + chr(8)*(len(status)+1)
+
+            status = "{0:16}".format(file_size_dl)
+            if file_size:
+                status += "   [{0:6.2f}%]".format(file_size_dl * 100 / file_size)
+            status += chr(13)
             print(status, end="")
+        print()
 
     return filename
 
@@ -83,5 +97,4 @@ if __name__ == '__main__':
         logging.info("=== Step {0} ===".format(step))
         res = f()
         os.system("{0} {1} {2}".format(sys.executable,
-                                    os.path.basename(__file__),
-                                    step+1))
+            os.path.basename(__file__), step+1))
